@@ -14,6 +14,14 @@ logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 
+def clean_filename(name, length=255):
+    forbidden_chars = "\"*\\/'.|?:<>"
+    filename = "".join([x if x not in forbidden_chars else "" for x in name])
+    if len(filename) > length:
+        filename = filename[: (length - 3)] + "..."
+    return filename
+
+
 def get_content_type(extension):
     """
     Returns the content type for a file extension.
@@ -37,6 +45,8 @@ def get_content_type(extension):
         content_type = "application/pdf"
     elif extension == "eml":
         content_type = "binary/octet-stream"
+    elif extension == "json":
+        content_type = "binary/octet-stream"
     else:
         return None
 
@@ -91,7 +101,15 @@ def make_json_from_csv(file, delimiter, encoding="utf-8"):
         logger.error(message)
         raise Exception(message)
 
-    csv.field_size_limit(sys.maxsize)
+    maxInt = sys.maxsize
+
+    while True:
+        try:
+            csv.field_size_limit(maxInt)
+            break
+        except OverflowError:
+            maxInt = int(maxInt / 10)
+
     # open file and read in as csv
     with open(file, "r", encoding=encoding) as f:
         csv_reader = csv.DictReader(f, delimiter=delimiter)
@@ -133,10 +151,15 @@ def randStr(chars=string.ascii_letters + string.digits, N=2):
 
 
 class Postgres:
-    def __init__(self, secrets_manager_key=None, host=None, port=None, user=None, password=None, dbname=None):
+    def __init__(
+        self, secrets_manager_key=None, host=None, port=None, user=None, password=None, dbname=None, profile=None
+    ):
         self.secrets_manager_key = secrets_manager_key
         if self.secrets_manager_key:
-            secret = json.loads(awsUtils.secrets_manager_get_secret(self.secrets_manager_key))
+            if not profile:
+                secret = json.loads(awsUtils.secrets_manager_get_secret(self.secrets_manager_key))
+            else:
+                secret = json.loads(awsUtils.secrets_manager_get_secret(self.secrets_manager_key, profile=profile))
             host = secret["host"]
             port = secret["port"]
             dbname = secret["dbname"]
